'
' <copyright file="RestHelpers.cs" company="Microsoft">
'     Copyright (c) Microsoft Corporation.  All rights reserved.
' </copyright>
'

Imports Microsoft.VisualBasic
Imports System
Imports System.Collections.Generic
Imports System.Linq
Imports System.Text
Imports System.IO
Imports System.Net
Imports System.Diagnostics
Imports System.Globalization
Imports System.Collections.Specialized
Imports System.Web
Imports System.Xml
Imports System.Text.RegularExpressions

Namespace Microsoft.Samples.ServiceHosting.StorageClient
	Namespace StorageHttpConstants

		Friend NotInheritable Class ConstChars
			Friend Const Linefeed As String = Constants.vbLf
			Friend Const CarriageReturnLinefeed As String = Constants.vbCrLf
			Friend Const Colon As String = ":"
			Friend Const Comma As String = ","
			Friend Const Slash As String = "/"
			Friend Const BackwardSlash As String = "\"
			Friend Const Space As String = " "
			Friend Const Ampersand As String = "&"
			Friend Const QuestionMark As String = "?"
			Friend Const Equal As String = "="
			Friend Const Bang As String = "!"
			Friend Const Star As String = "*"
			Friend Const Dot As String = "."
		End Class

		Friend NotInheritable Class RequestParams
			Friend Const NumOfMessages As String = "numofmessages"
			Friend Const VisibilityTimeout As String = "visibilitytimeout"
			Friend Const PeekOnly As String = "peekonly"
			Friend Const MessageTtl As String = "messagettl"
			Friend Const Messages As String = "messages"
			Friend Const PopReceipt As String = "popreceipt"
		End Class

		Friend NotInheritable Class QueryParams
			Friend Const SeparatorForParameterAndValue As String = "="
			Friend Const QueryParamTimeout As String = "timeout"
			Friend Const QueryParamComp As String = "comp"

			' Other query string parameter names
			Friend Const QueryParamBlockId As String = "blockid"
			Friend Const QueryParamPrefix As String = "prefix"
			Friend Const QueryParamMarker As String = "marker"
			Friend Const QueryParamMaxResults As String = "maxresults"
			Friend Const QueryParamDelimiter As String = "delimiter"
			Friend Const QueryParamModifiedSince As String = "modifiedsince"
		End Class

		Friend NotInheritable Class CompConstants
			Friend Const Metadata As String = "metadata"
			Friend Const List As String = "list"
			Friend Const BlobList As String = "bloblist"
			Friend Const BlockList As String = "blocklist"
			Friend Const Block As String = "block"
			Friend Const Acl As String = "acl"
		End Class

		Friend NotInheritable Class XmlElementNames
			Friend Const BlockList As String = "BlockList"
			Friend Const Block As String = "Block"
			Friend Const EnumerationResults As String = "EnumerationResults"
			Friend Const Prefix As String = "Prefix"
			Friend Const Marker As String = "Marker"
			Friend Const MaxResults As String = "MaxResults"
			Friend Const Delimiter As String = "Delimiter"
			Friend Const NextMarker As String = "NextMarker"
			Friend Const Containers As String = "Containers"
			Friend Const Container As String = "Container"
			Friend Const ContainerName As String = "Name"
			Friend Const ContainerNameAttribute As String = "ContainerName"
			Friend Const AccountNameAttribute As String = "AccountName"
			Friend Const LastModified As String = "LastModified"
			Friend Const Etag As String = "Etag"
			Friend Const Url As String = "Url"
			Friend Const CommonPrefixes As String = "CommonPrefixes"
			Friend Const ContentType As String = "ContentType"
			Friend Const ContentEncoding As String = "ContentEncoding"
			Friend Const ContentLanguage As String = "ContentLanguage"
			Friend Const Size As String = "Size"
			Friend Const Blobs As String = "Blobs"
			Friend Const Blob As String = "Blob"
			Friend Const BlobName As String = "Name"
			Friend Const BlobPrefix As String = "BlobPrefix"
			Friend Const BlobPrefixName As String = "Name"
			Friend Const Name As String = "Name"
			Friend Const Queues As String = "Queues"
			Friend Const Queue As String = "Queue"
			Friend Const QueueName As String = "QueueName"
			Friend Const QueueMessagesList As String = "QueueMessagesList"
			Friend Const QueueMessage As String = "QueueMessage"
			Friend Const MessageId As String = "MessageId"
			Friend Const PopReceipt As String = "PopReceipt"
			Friend Const InsertionTime As String = "InsertionTime"
			Friend Const ExpirationTime As String = "ExpirationTime"
			Friend Const TimeNextVisible As String = "TimeNextVisible"
			Friend Const MessageText As String = "MessageText"

			' Error specific constants
			Friend Const ErrorRootElement As String = "Error"
			Friend Const ErrorCode As String = "Code"
			Friend Const ErrorMessage As String = "Message"
			Friend Const ErrorException As String = "ExceptionDetails"
			Friend Const ErrorExceptionMessage As String = "ExceptionMessage"
			Friend Const ErrorExceptionStackTrace As String = "StackTrace"
			Friend Const AuthenticationErrorDetail As String = "AuthenticationErrorDetail"

			'The following are for table error messages
			Friend Const DataWebMetadataNamespace As String = "http://schemas.microsoft.com/ado/2007/08/dataservices/metadata"
			Friend Const TableErrorCodeElement As String = "code"
			Friend Const TableErrorMessageElement As String = "message"
		End Class

		Friend NotInheritable Class HeaderNames
			Friend Const PrefixForStorageProperties As String = "x-ms-prop-"
			Friend Const PrefixForMetadata As String = "x-ms-meta-"
			Friend Const PrefixForStorageHeader As String = "x-ms-"
			Friend Const PrefixForTableContinuation As String = "x-ms-continuation-"

			'
			' Standard headers...
			'
			Friend Const ContentLanguage As String = "Content-Language"
			Friend Const ContentLength As String = "Content-Length"
			Friend Const ContentType As String = "Content-Type"
			Friend Const ContentEncoding As String = "Content-Encoding"
			Friend Const ContentMD5 As String = "Content-MD5"
			Friend Const ContentRange As String = "Content-Range"
			Friend Const LastModifiedTime As String = "Last-Modified"
			Friend Const Server As String = "Server"
			Friend Const Allow As String = "Allow"
			Friend Const ETag As String = "ETag"
			Friend Const Range As String = "Range"
			Friend Const [Date] As String = "Date"
			Friend Const Authorization As String = "Authorization"
			Friend Const IfModifiedSince As String = "If-Modified-Since"
			Friend Const IfUnmodifiedSince As String = "If-Unmodified-Since"
			Friend Const IfMatch As String = "If-Match"
			Friend Const IfNoneMatch As String = "If-None-Match"
			Friend Const IfRange As String = "If-Range"
			Friend Const NextPartitionKey As String = "NextPartitionKey"
			Friend Const NextRowKey As String = "NextRowKey"
			Friend Const NextTableName As String = "NextTableName"

			'
			' Storage specific custom headers...
			'
			Friend Const StorageDateTime As String = PrefixForStorageHeader & "date"
			Friend Const PublicAccess As String = PrefixForStorageProperties & "publicaccess"
			Friend Const StorageRange As String = PrefixForStorageHeader & "range"

			Friend Const CreationTime As String = PrefixForStorageProperties & "creation-time"
			Friend Const ForceUpdate As String = PrefixForStorageHeader & "force-update"
			Friend Const ApproximateMessagesCount As String = PrefixForStorageHeader & "approximate-messages-count"
		End Class

		Friend NotInheritable Class HeaderValues
			Friend Const ContentTypeXml As String = "application/xml"

			''' <summary>
			''' This is the default content-type xStore uses when no content type is specified
			''' </summary>
			Friend Const DefaultContentType As String = "application/octet-stream"

			' The Range header value is "bytes=start-end", both start and end can be empty
			Friend Const RangeHeaderFormat As String = "bytes={0}-{1}"

		End Class

		Friend NotInheritable Class AuthenticationSchemeNames
			Friend Const SharedKeyAuthSchemeName As String = "SharedKey"
			Friend Const SharedKeyLiteAuthSchemeName As String = "SharedKeyLite"
		End Class

		Friend NotInheritable Class HttpMethod
			Friend Const [Get] As String = "GET"
			Friend Const Put As String = "PUT"
			Friend Const Post As String = "POST"
			Friend Const Head As String = "HEAD"
			Friend Const Delete As String = "DELETE"
			Friend Const Trace As String = "TRACE"
			Friend Const Options As String = "OPTIONS"
			Friend Const Connect As String = "CONNECT"
		End Class

		Friend NotInheritable Class BlobBlockConstants
			Friend Const KB As Integer = 1024
			Friend Const MB As Integer = 1024 * KB
			''' <summary>
			''' When transmitting a blob that is larger than this constant, this library automatically
			''' transmits the blob as individual blocks. I.e., the blob is (1) partitioned
			''' into separate parts (these parts are called blocks) and then (2) each of the blocks is 
			''' transmitted separately.
			''' The maximum size of this constant as supported by the real blob storage service is currently 
			''' 64 MB; the development storage tool currently restricts this value to 2 MB.
			''' Setting this constant can have a significant impact on the performance for uploading or
			''' downloading blobs.
			''' As a general guideline: If you run in a reliable environment increase this constant to reduce
			''' the amount of roundtrips. In an unreliable environment keep this constant low to reduce the 
			''' amount of data that needs to be retransmitted in case of connection failures.
			''' </summary>
			Friend Const MaximumBlobSizeBeforeTransmittingAsBlocks As Long = 2 * MB
			''' <summary>
			''' The size of a single block when transmitting a blob that is larger than the 
			''' MaximumBlobSizeBeforeTransmittingAsBlocks constant (see above).
			''' The maximum size of this constant is currently 4 MB; the development storage 
			''' tool currently restricts this value to 1 MB.
			''' Setting this constant can have a significant impact on the performance for uploading or 
			''' downloading blobs.
			''' As a general guideline: If you run in a reliable environment increase this constant to reduce
			''' the amount of roundtrips. In an unreliable environment keep this constant low to reduce the 
			''' amount of data that needs to be retransmitted in case of connection failures.
			''' </summary>
			Friend Const BlockSize As Long = 1 * MB
		End Class

		Friend NotInheritable Class ListingConstants
			Friend Const MaxContainerListResults As Integer = 100
			Friend Const MaxBlobListResults As Integer = 100
			Friend Const MaxQueueListResults As Integer = 50
			Friend Const MaxTableListResults As Integer = 50
		End Class

		''' <summary>
		''' Contains regular expressions for checking whether container and table names conform
		''' to the rules of the storage REST protocols.
		''' </summary>
		Public NotInheritable Class RegularExpressionStrings
			''' <summary>
			''' Container or queue names that match against this regular expression are valid.
			''' </summary>
			Public Const ValidContainerNameRegex As String = "^([a-z]|\d){1}([a-z]|-|\d){1,61}([a-z]|\d){1}$"

			''' <summary>
			''' Table names that match against this regular expression are valid.
			''' </summary>
			Public Const ValidTableNameRegex As String = "^([a-z]|[A-Z]){1}([a-z]|[A-Z]|\d){2,62}$"
		End Class

		Friend NotInheritable Class StandardPortalEndpoints
			Friend Const BlobStorage As String = "blob"
			Friend Const QueueStorage As String = "queue"
			Friend Const TableStorage As String = "table"
			Friend Const StorageHostSuffix As String = ".core.windows.net"
			Friend Const BlobStorageEndpoint As String = BlobStorage & StorageHostSuffix
			Friend Const QueueStorageEndpoint As String = QueueStorage & StorageHostSuffix
			Friend Const TableStorageEndpoint As String = TableStorage & StorageHostSuffix
		End Class
	End Namespace

	Friend Partial NotInheritable Class Utilities
        Friend Shared Function CreateHttpRequest(ByVal uri As Uri, ByVal httpMethod As String, ByVal timeout As TimeSpan) As HttpWebRequest
            Dim request As HttpWebRequest = CType(HttpWebRequest.Create(uri), HttpWebRequest)
            request.Timeout = CInt(Fix(timeout.TotalMilliseconds))
            request.ReadWriteTimeout = CInt(Fix(timeout.TotalMilliseconds))
            request.Method = httpMethod
            request.ContentLength = 0
            request.Headers.Add(StorageHttpConstants.HeaderNames.StorageDateTime, Utilities.ConvertDateTimeToHttpString(DateTime.UtcNow))
            Return request
        End Function

		''' <summary>
		''' Converts the date time to a valid string form as per HTTP standards
		''' </summary>
		Friend Shared Function ConvertDateTimeToHttpString(ByVal dateTime As DateTime) As String
			' On the wire everything should be represented in UTC. This assert will catch invalid callers who
			' are violating this rule.
			Debug.Assert(dateTime = DateTime.MaxValue OrElse dateTime = DateTime.MinValue OrElse dateTime.Kind = DateTimeKind.Utc)

			' 'R' means rfc1123 date which is what our server uses for all dates...
			' It will be in the following format:
			' Sun, 28 Jan 2008 12:11:37 GMT
			Return dateTime.ToString("R", CultureInfo.InvariantCulture)
		End Function

		''' <summary>
		''' Parse a string having the date time information in acceptable formats according to HTTP standards
		''' </summary>
		Friend Shared Function TryGetDateTimeFromHttpString(ByVal dateString As String, <System.Runtime.InteropServices.Out()> ByRef result? As DateTime) As Boolean
			Dim dateTime As DateTime
			result = Nothing

			' 'R' means rfc1123 date which is the preferred format used in HTTP
			Dim parsed As Boolean = DateTime.TryParseExact(dateString, "R", Nothing, DateTimeStyles.None, dateTime)
			If parsed Then
				' For some reason, format string "R" makes the DateTime.Kind as Unspecified while it's actually
				' Utc. Specifying DateTimeStyles.AssumeUniversal also doesn't make the difference. If we also
				' specify AdjustToUniversal it works as expected but we don't really want Parse to adjust 
				' things automatically.
				result = DateTime.SpecifyKind(dateTime, DateTimeKind.Utc)
				Return True
			End If

			Return False
		End Function


		''' <summary>
		''' Copies from one stream to another
		''' </summary>
		''' <param name="sourceStream">The stream to copy from</param>
		''' <param name="destinationStream">The stream to copy to</param>
		Friend Shared Function CopyStream(ByVal sourceStream As Stream, ByVal destinationStream As Stream) As Long
			Const BufferSize As Integer = &H10000
			Dim buffer(BufferSize - 1) As Byte
			Dim n As Integer = 0
			Dim totalRead As Long = 0
			Do
				n = sourceStream.Read(buffer, 0, BufferSize)
				If n > 0 Then
					totalRead += n
					destinationStream.Write(buffer, 0, n)
				End If

			Loop While n > 0
			Return totalRead
		End Function

		Friend Shared Sub CopyStream(ByVal sourceStream As Stream, ByVal destinationStream As Stream, ByVal length As Long)
			Const BufferSize As Integer = &H10000
			Dim buffer(BufferSize - 1) As Byte
			Dim n As Integer = 0
			Dim amountLeft As Long = length

			Do
				amountLeft -= n
				n = sourceStream.Read(buffer, 0, CInt(Fix(Math.Min(BufferSize, amountLeft))))
				If n > 0 Then
					destinationStream.Write(buffer, 0, n)
				End If

			Loop While n > 0
		End Sub

		Friend Shared Function CopyStreamToBuffer(ByVal sourceStream As Stream, ByVal buffer() As Byte, ByVal bytesToRead As Integer) As Integer
			Dim n As Integer = 0
			Dim amountLeft As Integer = bytesToRead
			Do
				n = sourceStream.Read(buffer, bytesToRead - amountLeft, amountLeft)
				amountLeft -= n
			Loop While n > 0
			Return bytesToRead - amountLeft
		End Function

		Friend Shared Function CreateRequestUri(ByVal baseUri As Uri, ByVal usePathStyleUris As Boolean, ByVal accountName As String, ByVal containerName As String, ByVal blobName As String, ByVal Timeout As TimeSpan, ByVal queryParameters As NameValueCollection, <System.Runtime.InteropServices.Out()> ByRef uriComponents As ResourceUriComponents) As Uri
			uriComponents = New ResourceUriComponents(accountName, containerName, blobName)
			Dim uri As Uri = HttpRequestAccessor.ConstructResourceUri(baseUri, uriComponents, usePathStyleUris)

			If queryParameters IsNot Nothing Then
				Dim builder As New UriBuilder(uri)

				If queryParameters.Get(StorageHttpConstants.QueryParams.QueryParamTimeout) Is Nothing Then
					queryParameters.Add(StorageHttpConstants.QueryParams.QueryParamTimeout, Timeout.TotalSeconds.ToString(CultureInfo.InvariantCulture))
				End If

				Dim sb As New StringBuilder()
				Dim firstParam As Boolean = True
				For Each queryKey As String In queryParameters.AllKeys
					If (Not firstParam) Then
						sb.Append("&")
					End If
					sb.Append(HttpUtility.UrlEncode(queryKey))
					sb.Append("="c)
					sb.Append(HttpUtility.UrlEncode(queryParameters(queryKey)))
					firstParam = False
				Next queryKey

				If sb.Length > 0 Then
					builder.Query = sb.ToString()
				End If
				Return builder.Uri
			Else
				Return uri
			End If
		End Function

		Friend Shared Function StringIsIPAddress(ByVal address As String) As Boolean
			Try
				IPAddress.Parse(address)

				' No exception means it's a valid IP address. 
				Return True
			Catch e1 As FormatException
				Return False
			End Try
		End Function

		Friend Shared Sub AddMetadataHeaders(ByVal request As HttpWebRequest, ByVal metadata As NameValueCollection)
			For Each key As String In metadata.Keys
				request.Headers.Add(StorageHttpConstants.HeaderNames.PrefixForMetadata & key, metadata(key))
			Next key
		End Sub

		Friend Shared Function IsValidTableName(ByVal name As String) As Boolean
			If String.IsNullOrEmpty(name) Then
				Return False
			End If
			Dim reg As New Regex(StorageHttpConstants.RegularExpressionStrings.ValidTableNameRegex)
			If reg.IsMatch(name) Then
				Return True
			Else
				Return False
			End If
		End Function

		Friend Shared Function IsValidContainerOrQueueName(ByVal name As String) As Boolean
			If String.IsNullOrEmpty(name) Then
				Return False
			End If
			Dim reg As New Regex(StorageHttpConstants.RegularExpressionStrings.ValidContainerNameRegex)
			If reg.IsMatch(name) Then
				Return True
			Else
				Return False
			End If
		End Function
	End Class
End Namespace
